@@ -1,7 +1,10 @@
-from PyQt5 import uic, QtCore
-from PyQt5.QtWidgets import QListWidgetItem, QApplication, QTableView, QHeaderView, QTableWidgetItem
+from PyQt5 import QtCore, uic
+from PyQt5.QtWidgets import (QApplication, QHeaderView, QListWidgetItem,
+                             QTableView, QTableWidgetItem)
+
+from vorta.store.models import (BackupProfileMixin, EventLogModel,
+                                WifiSettingModel)
 from vorta.utils import get_asset, get_sorted_wifis
-from vorta.models import EventLogModel, WifiSettingModel, BackupProfileMixin
 from vorta.views.utils import get_colored_icon
 
 uifile = get_asset('UI/scheduletab.ui')
@@ -45,7 +48,16 @@ class ScheduleTab(ScheduleBase, ScheduleUI, BackupProfileMixin):
         self.scheduleIntervalUnit.addItem(self.tr('Days'), 'days')
         self.scheduleIntervalUnit.addItem(self.tr('Weeks'), 'weeks')
 
-        # Populate with data
+        # Enable/Disable entries on button state changed
+        self.framePeriodic.setEnabled(False)
+        self.frameDaily.setEnabled(False)
+        self.frameValidation.setEnabled(False)
+
+        self.scheduleIntervalRadio.toggled.connect(self.framePeriodic.setEnabled)
+        self.scheduleFixedRadio.toggled.connect(self.frameDaily.setEnabled)
+        self.validationCheckBox.toggled.connect(self.frameValidation.setEnabled)
+
+        # POPULATE with data
         self.populate_from_profile()
         self.set_icons()
 
@@ -60,8 +72,8 @@ class ScheduleTab(ScheduleBase, ScheduleUI, BackupProfileMixin):
         self.scheduleFixedTime.timeChanged.connect(self.on_scheduler_change)
 
         # Network and shell commands events
-        self.dontRunOnMeteredNetworksCheckBox.stateChanged.connect(
-            lambda new_val, attr='dont_run_on_metered_networks': self.save_profile_attr(attr, new_val))
+        self.meteredNetworksCheckBox.stateChanged.connect(
+            lambda new_val, attr='dont_run_on_metered_networks': self.save_profile_attr(attr, not new_val))
         self.postBackupCmdLineEdit.textEdited.connect(
             lambda new_val, attr='post_backup_cmd': self.save_profile_attr(attr, new_val))
         self.preBackupCmdLineEdit.textEdited.connect(
@@ -77,6 +89,9 @@ class ScheduleTab(ScheduleBase, ScheduleUI, BackupProfileMixin):
         self.validationWeeksCount.valueChanged.connect(
             lambda new_val, attr='validation_weeks': self.save_profile_attr(attr, new_val))
 
+        # Connect to schedule update
+        self.app.scheduler.schedule_changed.connect(lambda pid: self.draw_next_scheduled_backup())
+
     def on_scheduler_change(self, _):
         profile = self.profile()
         # Save scheduler settings, apply new scheduler and display next task for profile.
@@ -121,8 +136,8 @@ class ScheduleTab(ScheduleBase, ScheduleUI, BackupProfileMixin):
             QtCore.Qt.Checked if profile.prune_on else QtCore.Qt.Unchecked)
         self.missedBackupsCheckBox.setCheckState(
             QtCore.Qt.Checked if profile.schedule_make_up_missed else QtCore.Qt.Unchecked)
-        self.dontRunOnMeteredNetworksCheckBox.setChecked(
-            QtCore.Qt.Checked if profile.dont_run_on_metered_networks else QtCore.Qt.Unchecked)
+        self.meteredNetworksCheckBox.setChecked(
+            QtCore.Qt.Unchecked if profile.dont_run_on_metered_networks else QtCore.Qt.Checked)
 
         self.preBackupCmdLineEdit.setText(profile.pre_backup_cmd)
         self.postBackupCmdLineEdit.setText(profile.post_backup_cmd)
